@@ -38,6 +38,7 @@ window.addEventListener("load", enigHdrViewLoad, false);
 addEventListener('messagepane-unloaded', enigHdrViewUnload, true);
 
 var gEnigStatusBar;
+var gEnigmailBox;
 
 function enigHdrViewLoad()
 {
@@ -48,54 +49,39 @@ function enigHdrViewLoad()
   var signedHdrElement = document.getElementById("signedHdrIcon");
   if (signedHdrElement) {
     signedHdrElement.setAttribute("onclick", "enigViewSecurityInfo(event, true);");
-    // signedHdrElement.setAttribute("context", "enigSecurityContext");
   }
 
   var encryptedHdrElement = document.getElementById("encryptedHdrIcon");
   if (encryptedHdrElement) {
     encryptedHdrElement.setAttribute("onclick", "enigViewSecurityInfo(event, true);");
-    // encryptedHdrElement.setAttribute("context", "enigSecurityContext");
   }
 
   gEnigStatusBar = document.getElementById("enigmail-status-bar");
+  gEnigmailBox = document.getElementById("enigmailBox");
+
+}
+
+function enigStatusBarHide() {
+  try {
+    gEnigStatusBar.removeAttribute("signed");
+    gEnigStatusBar.removeAttribute("encrypted");
+    gEnigmailBox.setAttribute("collapsed", "true")
+  }
+  catch (ex) {}
 }
 
 function enigStartHeaders()
 {
   DEBUG_LOG("enigmailMsgHdrViewOverlay.js: enigStartHeaders\n");
 
-  //var hideHeaderBox = document.getElementById();
   try {
-    var index;
-    var hideHeaders = EnigGetPref("hideHeaders").split(' ');
-    for (index = 0; index < hideHeaders.length; index++) {
-      if (typeof(gExpandedHeaderView[hideHeaders[index]]) == "object") {
-        if (! gViewAllHeaders) {
-          gExpandedHeaderView[hideHeaders[index]].enclosingBox.setAttribute("hidden", true);
-        }
-        else {
-          gExpandedHeaderView[hideHeaders[index]].enclosingBox.removeAttribute("hidden");
-        }
-      }
-    }
 
-    gEnigStatusBar.removeAttribute("signed");
-    gEnigStatusBar.removeAttribute("encrypted");
+    enigStatusBarHide();
 
-    var enigmailBox = document.getElementById("enigmailBox");
     var statusText = document.getElementById("enigmailStatusText");
-    var statusTextBox = document.getElementById("enigmailStatusTextBox");
-    var statusHdrButton = document.getElementById("enigmailBox");
+    if (statusText) statusText.value="";
 
-    if (enigmailBox && !enigmailBox.collapsed) {
-      enigmailBox.setAttribute("collapsed", "true");
-
-      if (statusText) statusText.value="";
-    }
-
-//    statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureOk");
-    statusHdrButton.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelSignatureOk");
-//    statusTextBox.setAttribute("class", "enigmailHeaderNameBox enigmailHeaderBoxLabelSignatureOk");
+    gEnigmailBox.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelSignatureOk");
     
     var msgFrame = EnigGetFrame(window, "messagepane");
 
@@ -106,7 +92,7 @@ function enigStartHeaders()
       msgFrame.addEventListener("load", enigMessageAutoDecrypt, false);
     }
 
-    enigForgetEncryptedURI();
+    enigForgetEncryptedMsgKey();
 
     if (messageHeaderSink) {
       try {
@@ -123,14 +109,10 @@ function enigEndHeaders()
 {
   DEBUG_LOG("enigmailMsgHdrViewOverlay.js: enigEndHeaders\n");
   try {
-    gEnigStatusBar.removeAttribute("signed");
-    gEnigStatusBar.removeAttribute("encrypted");
+    enigStatusBarHide();
     var statusText = document.getElementById("enigmailStatusText");
-    var statusHdrButton = document.getElementById("enigmailBox");
 
-//    statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureOk");
-    statusHdrButton.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelSignatureOk");
-//    statusTextBox.setAttribute("class", "enigmailHeaderNameBox enigmailHeaderBoxLabelSignatureOk");
+    gEnigmailBox.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelSignatureOk");
   }
   catch (ex) {}
 }
@@ -141,7 +123,7 @@ function enigBeforeStartHeaders() {
 
 // Match the userId from gpg to the sender's from address
 function enigMatchUidToSender(userId) {
-  var fromAddr = currentHeaderData["from"].headerValue;
+  var fromAddr = gFolderDisplay.selectedMessage.author;
   try {
     fromAddr=EnigStripEmail(fromAddr);
   }
@@ -166,7 +148,9 @@ function enigMatchUidToSender(userId) {
 function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, errorMsg, blockSeparation) {
   DEBUG_LOG("enigmailMsgHdrViewOverlay.js: enigUpdateHdrIcons: exitCode="+exitCode+", statusFlags="+statusFlags+", keyId="+keyId+", userId="+userId+", "+errorMsg+"\n");
 
-  gEnigLastEncryptedURI = GetLoadedMessage();
+  if (gFolderDisplay.selectedMessageUris.length > 0) {
+    gEnigLastEncryptedMsgKey = gFolderDisplay.selectedMessageUris[0];
+  }
   var bodyElement = document.getElementById("messagepanebox");
 
   if (!errorMsg) errorMsg="";
@@ -382,11 +366,8 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
                         fullStatusInfo: fullStatusInfo,
                         blockSeparation: blockSeparation };
 
-  var enigmailBox = document.getElementById("enigmailBox");
   var statusText  = document.getElementById("enigmailStatusText");
-  var statusTextBox = document.getElementById("enigmailStatusTextBox");
   var expStatusText  = document.getElementById("expandedEnigmailStatusText");
-  var statusHdrButton = document.getElementById("enigmailBox");
   
   if (statusArr.length>0) {
     expStatusText.value = statusArr[0];
@@ -399,11 +380,11 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
 
   if (statusLine) {
     statusText.value = statusLine +" ";
-    enigmailBox.removeAttribute("collapsed");
+    gEnigmailBox.removeAttribute("collapsed");
     enigDisplayExtendedStatus(true);
   } else {
     statusText.value = "";
-    enigmailBox.setAttribute("collapsed", "true");
+    gEnigmailBox.setAttribute("collapsed", "true");
     enigDisplayExtendedStatus(false);
   }
 
@@ -419,9 +400,7 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
     if (statusFlags & nsIEnigmail.BAD_SIGNATURE) {
       // Display untrusted/bad signature icon
       gSignedUINode.setAttribute("signed", "notok");
-//      statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureNotOk");
-//      statusTextBox.setAttribute("class", "enigmailHeaderNameBox enigmailHeaderBoxLabelSignatureNotOk");
-      statusHdrButton.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelSignatureNotOk");
+      gEnigmailBox.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelSignatureNotOk");
       gEnigStatusBar.setAttribute("signed", "notok");
     }
     else if ((statusFlags & nsIEnigmail.GOOD_SIGNATURE) &&
@@ -431,18 +410,14 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
                        nsIEnigmail.EXPIRED_SIGNATURE))) {
       // Display trusted good signature icon
       gSignedUINode.setAttribute("signed", "ok");
-//      statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureOk");
-//      statusTextBox.setAttribute("class", "enigmailHeaderNameBox enigmailHeaderBoxLabelSignatureOk");
-      statusHdrButton.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelSignatureOk");
+      gEnigmailBox.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelSignatureOk");
       gEnigStatusBar.setAttribute("signed", "ok");
       bodyElement.setAttribute("enigSigned", "ok");
     }
     else if (statusFlags & nsIEnigmail.UNVERIFIED_SIGNATURE) {
       // Display unverified signature icon
       gSignedUINode.setAttribute("signed", "unknown");
-//      statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureUnknown");
-//      statusTextBox.setAttribute("class", "enigmailHeaderNameBox enigmailHeaderBoxLabelSignatureUnknown");
-      statusHdrButton.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelSignatureUnknown");
+      gEnigmailBox.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelSignatureUnknown");
       gEnigStatusBar.setAttribute("signed", "unknown");
     }
     else if (statusFlags & (nsIEnigmail.REVOKED_KEY |
@@ -451,27 +426,21 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
                        nsIEnigmail.GOOD_SIGNATURE)) {
       // Display unverified signature icon
       gSignedUINode.setAttribute("signed", "unknown");
-//      statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureVerified");
-//      statusTextBox.setAttribute("class", "enigmailHeaderNameBox enigmailHeaderBoxLabelSignatureVerified");
-      statusHdrButton.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelSignatureVerified");
+      gEnigmailBox.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelSignatureVerified");
       gEnigStatusBar.setAttribute("signed", "unknown");
     }
     else if (statusFlags & nsIEnigmail.INLINE_KEY) {
-//      statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureUnknown");
-      statusHdrButton.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelSignatureUnknown");
-//      statusTextBox.setAttribute("class", "enigmailHeaderNameBox enigmailHeaderBoxLabelSignatureUnknown");
+      gEnigmailBox.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelSignatureUnknown");
     }
     else {
-//      statusText.setAttribute("class", "plain enigmailHeaderNameBox enigmailHeaderBoxLabelNoSignature");
-      statusHdrButton.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelNoSignature");
-//      statusTextBox.setAttribute("class", "enigmailHeaderNameBox enigmailHeaderBoxLabelNoSignature");
+      gEnigmailBox.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelNoSignature");
     }
 
     if (statusFlags & nsIEnigmail.DECRYPTION_OKAY) {
       var enigMimeService = Components.classes[ENIG_ENIGMIMESERVICE_CONTRACTID].getService(Components.interfaces.nsIEnigMimeService);
       if (enigMimeService)
       {
-        enigMimeService.rememberEncrypted(gEnigLastEncryptedURI);
+        enigMimeService.rememberEncrypted(gEnigLastEncryptedMsgKey);
       }
 
       // Display encrypted icon
@@ -483,9 +452,7 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
       // Display un-encrypted icon
       gEncryptedUINode.setAttribute("encrypted", "notok");
       gEnigStatusBar.setAttribute("encrypted", "notok");
-//      statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureNotOk");
-      statusHdrButton.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelSignatureNotOk");
-//      statusTextBox.setAttribute("class", "enigmailHeaderNameBox enigmailHeaderBoxLabelSignatureNotOk");
+      gEnigmailBox.setAttribute("class", "expandedEnigmailBox enigmailHeaderBoxLabelSignatureNotOk");
     }
 
   } catch (ex) {}
@@ -588,7 +555,7 @@ function enigMessageUnload() {
 
 function enigHdrViewUnload() {
   DEBUG_LOG("enigmailMsgHdrViewOverlay.js: enigHdrViewUnLoad\n");
-  enigForgetEncryptedURI();
+  enigForgetEncryptedMsgKey();
 }
 
 function enigCopyStatusInfo() {
@@ -610,26 +577,28 @@ function enigShowPhoto() {
 function enigCreateRuleFromAddress(emailAddressNode) {
   if (emailAddressNode)
   {
+    if (typeof(findEmailNodeFromPopupNode)=="function") {
+      emailAddressNode = findEmailNodeFromPopupNode(emailAddressNode, 'emailAddressPopup');
+    }
     EnigNewRule(emailAddressNode.getAttribute("emailAddress"));
   }
 }
 
-function enigForgetEncryptedURI()
+function enigForgetEncryptedMsgKey()
 {
-  if (gEnigLastEncryptedURI)
+  if (gEnigLastEncryptedMsgKey)
   {
     var enigMimeService = Components.classes[ENIG_ENIGMIMESERVICE_CONTRACTID].getService(Components.interfaces.nsIEnigMimeService);
     if (enigMimeService) {
-      enigMimeService.forgetEncrypted(gEnigLastEncryptedURI);
-      gEnigLastEncryptedURI = null;
+      enigMimeService.forgetEncrypted(gEnigLastEncryptedMsgKey);
+      gEnigLastEncryptedMsgKey = null;
     }
   }
 }
 
 function enigMsgHdrViewHide() {
   DEBUG_LOG("enigmailMsgHdrViewOverlay.js: enigMsgHdrViewHide\n");
-  var enigmailBox = document.getElementById("enigmailBox");
-  enigmailBox.setAttribute("collapsed", true);
+  gEnigmailBox.setAttribute("collapsed", true);
 
   gEnigSecurityInfo = { statusFlags: 0,
                       keyId: "",
@@ -643,8 +612,7 @@ function enigMsgHdrViewHide() {
 function enigMsgHdrViewUnhide() {
   DEBUG_LOG("enigmailMsgHdrViewOverlay.js: enigMsgHdrViewUnhide\n");
   if (gEnigSecurityInfo.statusFlags != 0) {
-    var enigmailBox = document.getElementById("enigmailBox");
-    enigmailBox.removeAttribute("collapsed");
+    gEnigmailBox.removeAttribute("collapsed");
   }
 }
 
@@ -664,19 +632,19 @@ function enigDisplayExtendedStatus(displayMe) {
 }
 
 function enigToggleHeaderView() {
-  var viewToggle = document.getElementById("enigToggleHeaderView");
+  var viewToggle = document.getElementById("enigToggleHeaderView2");
   var expandedText = document.getElementById("expandedEnigmailStatusText");
   var state = viewToggle.getAttribute("state");
 
   if (state=="true") {
     viewToggle.setAttribute("state", "false");
-    viewToggle.setAttribute("class", "collapsedHeaderViewButton");
+    viewToggle.setAttribute("class", "enigmailExpandViewButton");
     expandedText.setAttribute("display", "false");
     enigDisplayExtendedStatus(false);
   }
   else {
     viewToggle.setAttribute("state", "true");
-    viewToggle.setAttribute("class", "expandHeaderViewButton");
+    viewToggle.setAttribute("class", "enigmailCollapseViewButton");
     expandedText.setAttribute("display", "true");
     enigDisplayExtendedStatus(true);
   }
@@ -762,14 +730,14 @@ addEventListener('messagepane-unhide', enigMsgHdrViewUnhide, true);
 
 function CanDetachAttachments()
 {
-  var uri = GetLoadedMessage();
-  var canDetach = !IsNewsMessage(uri) && (!IsImapMessage(uri) || MailOfflineMgr.isOnline());
+  var canDetach = !gFolderDisplay.selectedMessageIsNews &&
+                  (!gFolderDisplay.selectedMessageIsImap || MailOfflineMgr.isOnline());
 
   if (canDetach && ("content-type" in currentHeaderData))
   {
     var contentType = currentHeaderData["content-type"].headerValue;
-    canDetach = contentType.indexOf("application/x-pkcs7-mime") < 0 &&
-        contentType.indexOf("application/x-pkcs7-signature") < 0;
+    
+    canDetach = !ContentTypeIsSMIME(currentHeaderData["content-type"].headerValue);
   }
   return canDetach && enigCanDetachAttachments();
 }
@@ -863,35 +831,3 @@ EnigMimeHeaderSink.prototype =
 
 };
 
-function createEnum() {
-  var enumObj = {
-    _data: new Array(),
-    _index: 0,
-
-    addValue: function (strVal) {
-      this._data.push(strVal);
-    },
-
-    hasMore: function () {
-      return this._data.length > this._index;
-    },
-
-    getNext: function () {
-      if (this._data.length > this._index) {
-        var idx = this._index;
-        ++this._index;
-        return this._data[idx];
-      }
-      else {
-        return null;
-      }
-    },
-
-    resetEnum: function () {
-      this._index = 0;
-    }
-  }
-
-  return enumObj;
-}
-
